<?php
/*
Plugin Name: Announcer
Plugin URI: http://www.aakashweb.com
Description: Display Announcements, Welcome notes, Greetings, Events, News etc with attractive style, colors, themes and position it anywhere in the page. <a href="http://www.youtube.com/watch?v=WTLHuoY0mM0" title="Announcer demo video" target="_blank">Check out the demo video</a>.
Author: Aakash Chakravarthy
Version: 2.1
Author URI: http://www.aakashweb.com/
*/

if(!defined('WP_CONTENT_URL')) {
	$ancr_url = get_option('siteurl') . '/wp-content/plugins/' . plugin_basename(dirname(__FILE__)).'/';
}else{
	$ancr_url = WP_CONTENT_URL . '/plugins/' . plugin_basename(dirname(__FILE__)) . '/';
}

define('ANCR_VERSION', '2.1');
define('ANCR_AUTHOR', 'Aakash Chakravarthy');
define('ANCR_URL', $ancr_url);

$ancr_donate_link = 'http://bit.ly/ancrdonate';

// Load languages
load_plugin_textdomain('announcer', false, basename(dirname(__FILE__)) . '/languages/');

// Admin menu
function ancr_addpage() {
    add_submenu_page('options-general.php', 'Announcer', 'Announcer', 10, 'announcer', 'ancr_admin_page');
}
add_action('admin_menu', 'ancr_addpage');

// Load the Javascripts
function ancr_admin_js() {
	if (isset($_GET['page']) && $_GET['page'] == 'announcer'){
		wp_enqueue_script('jquery'); 
		wp_enqueue_script('announcer-admin-js', ANCR_URL . 'ancr-admin-js.js');
		wp_enqueue_script('announcer-editor-js', ANCR_URL . 'js/jwysiwyg/jquery.wysiwyg.js');
		wp_enqueue_script('announcer-colorpicker-js', ANCR_URL . 'js/colorpicker/farbtastic.js');
	}
}
add_action('admin_print_scripts', 'ancr_admin_js');

// Load the CSS
function ancr_admin_css() {
	if (isset($_GET['page']) && $_GET['page'] == 'announcer') {
		wp_enqueue_style('announcer-admin-css', ANCR_URL . 'ancr-admin-css.css');
		wp_enqueue_style('announcer-editor-css', ANCR_URL . 'js/jwysiwyg/jquery.wysiwyg.css');
		wp_enqueue_style('announcer-colorpicker-css', ANCR_URL . 'js/colorpicker/farbtastic.css');
	}
}
add_action('admin_print_styles', 'ancr_admin_css');

// Insert the required javascripts and styles to the theme
if( !is_admin()){
	// jQuery
	wp_deregister_script('jquery');
	wp_register_script('jquery', ("http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js"), false, '1.3.2');
	wp_enqueue_script('jquery');
	
	// Announcer JS and CSS
	wp_register_script('announcer-js', ANCR_URL . 'public/announcer-js.js');
	wp_enqueue_script('announcer-js');
	wp_register_style('announcer-css', ANCR_URL . 'public/announcer-styles.css');
	wp_enqueue_style('announcer-css');
}

/**
 *
 * Basic functions for the plugin
 *
 **/
 
function ancr_check_user_date(){
	$options = get_option('announcer_data');
	$announcer_expdate = $options['announcer_expdate'];
	
	if($announcer_expdate == 0){
		return 1;
	}
	
	$announcer_date_hyphen = strpos($announcer_expdate, '-');
	
	if ($announcer_date_hyphen === false) {
		return 0;
	} else {
		list($year, $month, $day) = explode('-', $announcer_expdate);
		if($year > 2009){ $year_check = 1;}
		if($month < 12 && $month != 0){ $month_check = 1; }
		if($day < 31 && $day != 0){ $day_check = 1; }
		if($year_check == 1 && $month_check == 1 && $day_check == 1){
			return 1;
		}
	}
}

// Compare the present and the end date.
function ancr_compare_dates(){
	$options = get_option('announcer_data');
	
	$announcer_expdate = strtotime($options['announcer_expdate']);
	$announcer_todays_date = strtotime(date('Y-n-d'));
	
	if (($announcer_expdate > $announcer_todays_date) || $announcer_expdate == 0){
		return 1;
	}else{
		return 0;
	}
}

// Revision checker
function ancr_revision(){
	
	$options = get_option('announcer_data');
	$announcer_revision = $options['announcer_revision'];
	
	if($_COOKIE['announcer-revision'] != $announcer_revision){
		setcookie("announcer-revision", $announcer_revision, time() + 60*60*24*365, '/');
		setcookie("announcer-state" , "visible", time() + 60*60*24*365 , '/');
	}
}
add_action('init', 'ancr_revision');

// Main function
function announcer(){
	static $announcer_is_added;
	
	if($announcer_is_added != 'yes' && $announcer_is_added == NULL){
		$options = get_option('announcer_data');
		
		$announcer_status = $options['announcer_status'];
		$announcer_previous_content = stripslashes($options['announcer_previous_content']);
		$announcer_content = stripslashes($options['announcer_content']);
		$announcer_expdate = $options['announcer_expdate'];
		$announcer_closebt = $options['announcer_closebt'];
		$announcer_position = $options['announcer_position'];
		$announcer_style = $options['announcer_style'];
		$announcer_stylecolors = $options['announcer_stylecolors'];
		$announcer_customclass = $options['announcer_customclass'];
		
		$announcer_revision = $options['announcer_revision'];
		
		// Get close button
		if ($announcer_closebt == 'yes'){
			$announcer_close_button = "\n" . '<span class="announcer_closebt">x</span>' . "\n";
		}else{
			$announcer_close_button = '';
		}
		
		// Get box style
		if ($announcer_style == 'custom'){
			$announcer_style = $announcer_customclass;
		}else{
			$announcer_style = 'announcer_' . $announcer_style;
			$colorssplit = explode(',', $announcer_stylecolors);
			$style = ' style="border-color:' . $colorssplit[0] . '; background-color:' . $colorssplit[1] . '; color: ' . $colorssplit[2] . '" ';
		}
		
		// Top and bottom fix classes
		if($announcer_position == 'top-float' || $announcer_position == 'bottom-float'){
			$announcer_style =  'announcer_' . $announcer_position . ' ' . $announcer_style;
		}
		
		// Main output
		if ($announcer_status == "1" && ancr_compare_dates()){
			echo "<!-- Start Announcement - Announcer plugin -->\n";
			echo '<div id="announcer_box" class="' . $announcer_style . '"' . $style . '>' . $announcer_close_button . '<div class="announcer_content">' . $announcer_content . '</div>';
			echo '<span class="announcer_credits"><a href="http://www.aakashweb.com">Aakash Web</a> <a href="http://www.aakashweb.com/wordpress-plugins/announcer/">Announcer plugin</a></span>';
			echo "</div>\n";
			echo "<!-- End Announcement - Announcer plugin -->\n";
			$announcer_is_added = 'yes';
		}
	}
}

function ancr_insert(){
	$options = get_option('announcer_data');
	$announcer_position = $options['announcer_position'];
	
	if(!is_admin()){
	
		if($announcer_position == 'top-fixed'){
			add_action('loop_start', 'announcer');	
		}
		
		if($announcer_position == 'bottom-fixed'){
			add_action('loop_end', 'announcer');
		}
		
		if($announcer_position == 'top-float' || $announcer_position == 'bottom-float'){
			add_action('wp_footer', 'announcer');
		}
		
	}
}
add_action('init', 'ancr_insert');

// Announcer admin page.
function ancr_admin_page(){
		
	$announcer_updated = false;
	$options = get_option('announcer_data');

	// Announcer date entry check
	if(!$_POST["ancr_submit"] && ancr_compare_dates() == 0){
		$options = get_option('announcer_data');
		$options['announcer_status'] = 0;
		update_option('announcer_data', $options);
		
		echo '<div class="message error fade"><p>' . sprintf(__('The date <code>%s</code> has expired. Announcement is turned off', 'announcer'), $options['announcer_expdate']) . '</p></div>';
	}
	
	// Announce main admin form
	if ($_POST["ancr_submit"]) {
		
		// Default msg
		$announcer_msg = __('Updated successfully !', 'announcer');
		
		// If no data is entered
		if($_POST['announcer_expdate'] == NULL){
			$_POST['announcer_expdate'] = 0; 
		}
		
		// Getting the posted datas
		$options['announcer_previous_content'] = $options['announcer_content'];
		$options['announcer_status'] = $_POST['announcer_status'];
		$options['announcer_expdate'] = $_POST['announcer_expdate'];
		$options['announcer_closebt'] = $_POST['announcer_closebt'];
		$options['announcer_position'] = $_POST['announcer_position'];
		$options['announcer_style'] = $_POST['announcer_style'];
		$options['announcer_stylecolors'] = $_POST['announcer_stylecolors'];
		$options['announcer_customclass'] = $_POST['announcer_customclass'];
		
		if($options['announcer_previous_content'] != $_POST['announcer_content']){
			$options['announcer_content'] = $_POST['announcer_content'];
			$options['announcer_revision'] = $options['announcer_revision'] + 1 ;
		}else{
			$announcer_msg = __('Announcement content is not changed. Other options are updated !', 'announcer');
		}
		
		// Update to the DB
		update_option("announcer_data", $options);
		$announcer_updated = true; 
		
		// Updated message
		if($announcer_updated == true){
			echo '<div class="message updated fade"><p>' . $announcer_msg . '</p></div>';
		}else{
			echo '<div class="message error fade"><p>' . __('Unable to update !', 'announcer') . '</p></div>';
		}
		
		// Check whether date is valid
		if(ancr_compare_dates() == 0 || ancr_check_user_date() == 0){
			echo '<div class="message error fade"><p>' . sprintf(__('The date <code>%s</code> has expired or invalid. Please check the date. Format is <code>YYYY-MM-DD</code>', 'announcer'), $options['announcer_expdate']) . '</p></div>';
			$announcer_expdate_class = 'style="border: 1px solid #FF0000;"';
		}
	}
	
	// Retrieve and assign the new data to variables
	$announcer_status = $options['announcer_status'];
	$announcer_content = stripslashes($options['announcer_content']);
	$announcer_expdate = $options['announcer_expdate'];
	$announcer_closebt = $options['announcer_closebt'];
	$announcer_position = $options['announcer_position'];
	
	$announcer_style = $options['announcer_style'];
	$announcer_customclass = $options['announcer_customclass'];
	$announcer_stylecolors = ($options['announcer_stylecolors'] == '') ? '#cccccc,#F9F9F9,#000000' : $options['announcer_stylecolors'];
	
?>

<!-- Announcer admin page Start-->

<div class="wrap">

<?php ancr_fbbutton(); ?>

<h2><img width="32" height="32" src="<?php echo ANCR_URL; ?>images/announcer.png" align="absmiddle"/>&nbsp;Announcer<span class="smallText"> v<?php echo ANCR_VERSION; ?></span></h2>

<ul class="ancr_share_wrap">
<li class="ancr_donate" data-width="300" data-height="220" data-url="<?php echo ANCR_URL . 'js/share.php?i=1'; ?>"><a href="#"></a></li>
<li class="ancr_share"  data-width="350" data-height="85" data-url="<?php echo ANCR_URL . 'js/share.php?i=2'; ?>"><a href="#"></a></li>
</ul>

<div id="content">

	<form method="post" id="ancr_form">
		<input name="announcer_status" id="announcer_status" type="hidden" value="<?php echo $announcer_status;?>" />
		
		<h3>Announcement</h3>
		<div class="section">
			<textarea  name="announcer_content" rows="10" id="announcer_content"><?php echo $announcer_content; ?></textarea>
			
			<div class="announcer_statuswrap">
				<span id="announcer_statusbt" title="<?php _e('Click to toggle showing announcements on and off', 'announcer'); ?>"></span>
			</div>
			
		</div>
		
		<h3>Settings</h3>
		<div class="section">
			<table width="100%" border="0">
			  <tr>
				<td height="36">Expiry Date</td>
				<td><input type="text" id="announcer_expdate"  name="announcer_expdate" value="<?php echo $announcer_expdate; ?>" <?php echo $announcer_expdate_class; ?> /><br/>
				<span class="smallText"><?php _e('Format is YYYY-MM-DD | 0 for no limit', 'announcer'); ?></span>
				</td>
			  </tr>
			  <tr>
				<td height="36">Show close button</td>
				<td>
		<select name="announcer_closebt" id="announcer_closebt">
		  <option <?php echo $announcer_closebt == 'yes' ? ' selected="selected"' : ''; ?> value="yes"><?php _e('Yes', 'announcer'); ?></option>
		  <option <?php echo $announcer_closebt == 'no' ? ' selected="selected"' : ''; ?> value="no"><?php _e('No', 'announcer'); ?></option>
		</select>
			</td>
			  </tr>
			  
			   <tr>
				<td height="36">Announcement position</td>
				<td>
		<select id="announcer_position" name="announcer_position">
			<option <?php echo $announcer_position == 'top-fixed' ? ' selected="selected"' : ''; ?> value="top-fixed">Top Fixed</option>
			<option <?php echo $announcer_position == 'bottom-fixed' ? ' selected="selected"' : ''; ?> value="bottom-fixed">Bottom Fixed</option>
			<option <?php echo $announcer_position == 'top-float' ? ' selected="selected"' : ''; ?> value="top-float">Top Float</option>
			<option <?php echo $announcer_position == 'bottom-float' ? ' selected="selected"' : ''; ?> value="bottom-float">Bottom Float</option>
			<option <?php echo $announcer_position == 'manual' ? ' selected="selected"' : ''; ?> value="manual">Manual placement</option>
		</select>
		</td>
			  </tr>
			</table>
		</div>
		
		<h3>Themes and Styles</h3>
	  <div class="section" style="position:relative">
		
			<table width="100%" border="0">
			
				<tr>
					<td width="41%" height="36">Box style</td>
				  <td width="59%">
			<select id="announcer_style" name="announcer_style">
				<option <?php echo $announcer_style == 'style1' ? ' selected="selected"' : ''; ?> value="style1">Style 1</option>
				<option <?php echo $announcer_style == 'style2' ? ' selected="selected"' : ''; ?> value="style2">Style 2</option>
				<option <?php echo $announcer_style == 'style3' ? ' selected="selected"' : ''; ?> value="style3">Style 3</option>
				<option <?php echo $announcer_style == 'style4' ? ' selected="selected"' : ''; ?> value="style4">Style 4</option>
				<option <?php echo $announcer_style == 'style5' ? ' selected="selected"' : ''; ?> value="style5">Style 5</option>
				<option <?php echo $announcer_style == 'style6' ? ' selected="selected"' : ''; ?> value="style6">Style 6</option>
				<option <?php echo $announcer_style == 'style7' ? ' selected="selected"' : ''; ?> value="style7">Style 7</option>
				<option <?php echo $announcer_style == 'style8' ? ' selected="selected"' : ''; ?> value="style8">Style 8</option>
				<option <?php echo $announcer_style == 'style9' ? ' selected="selected"' : ''; ?> value="style9">Style 9</option>
				<option <?php echo $announcer_style == 'style10' ? ' selected="selected"' : ''; ?> value="style10">Style 10</option>
				<option <?php echo $announcer_style == 'custom' ? ' selected="selected"' : ''; ?> value="custom">Custom class</option>
			</select>
			
			&nbsp; <small class="announcer_ccolor"><a href="<?php echo ANCR_URL . 'js/styles-preview.php'; ?>" target="_blank">Preview styles</a></small>
			
			</td>
			  </tr>
				  
				  <tr height="36" class="announcer_cclass">
					<td height="36">Custom "class" name</td>
					<td><input type="text" id="announcer_customclass"  name="announcer_customclass" value="<?php echo $announcer_customclass; ?>" /></td>
				  </tr>
				  <tr height="36" class="announcer_ccolor">
				    <td height="36">Border Color </td>
				    <td><input type="text" class="announcer_borderclr cpicker" /></td>
		      </tr>
				  <tr height="36" class="announcer_ccolor">
				    <td height="36">Background Color </td>
				    <td><input type="text" class="announcer_bgclr cpicker" /></td>
		      </tr>
				  <tr height="36" class="announcer_ccolor">
				    <td height="36">Text color </td>
				    <td><input type="text" class="announcer_textclr cpicker" /></td>
		      </tr>
			  
			</table>
			
			<input type="hidden" id="announcer_stylecolors"  name="announcer_stylecolors" value="<?php echo $announcer_stylecolors; ?>" />
			<div id="announcer_colorpicker"></div>
		
		  <p class="ancr_manualplace">Manual Placement code: <code>&lt;?php if(function_exists('announcer')) { announcer();} ?&gt;</code></p>
		
		</div>
		
		<input id="ancr_submit" type="submit" name="ancr_submit" class="button-primary" value="Update" />
		
	</form>

</div>

<p align="center"><a href="http://www.aakashweb.com/forum/" target="_blank">Report bugs</a> | <a href="http://www.aakashweb.com/forum/" target="_blank">Support Forum</a> | <a href="http://www.aakashweb.com/wordpress-plugins/announcer/" target="_blank">Documentation</a> | <a href="http://www.aakashweb.com/wordpress-plugins/announcer/" target="_blank">Help</a> | <a href="http://bit.ly/ancrdonate" target="_blank">Donate</a><br><br>
<a href="#" class="ancr_open_video">(Demo video)</a><br><br>
<a href="https://twitter.com/vaakash" target="_blank" class="twitter-follow-button" data-show-count="false" data-width="130px" data-align="center">Follow @vaakash</a><br><br>
<a href="http://www.aakashweb.com/" target="_blank" class="ancr_credits">a Aakash Web plugin</a></p>

</div>

<?php 
}

// Action Links
function ancr_plugin_actions($links, $file){
	static $this_plugin;
	global $ancr_donate_link;
	
	if(!$this_plugin) $this_plugin = plugin_basename(__FILE__);
	if( $file == $this_plugin ){
		$settings_link = "<a href='$ancr_donate_link' title='If you like this plugin, then just make a small Donation to continue this plugin development.' target='_blank'>" . __('Make Donations', 'hja') . '</a> ';
		$links = array_merge(array($settings_link), $links);
	}
	return $links;
}
add_filter('plugin_action_links', 'ancr_plugin_actions', 10, 2);

function ancr_fbbutton(){
	echo '<iframe src="//www.facebook.com/plugins/like.php?href=http%3A%2F%2Ffacebook.com%2Faakashweb&amp;send=false&amp;layout=button_count&amp;width=450&amp;show_faces=true&amp;action=recommend&amp;colorscheme=light&amp;font=arial&amp;height=21&amp;appId=106994469342299" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width: 126px; height:21px;float: right;margin-top: 15px;" allowtransparency="true"></iframe>';
}

?>